Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1067)

Unified Diff: net/url_request/fraudulent_certificate_reporter.h

Issue 935663004: Add checkbox for reporting invalid TLS/SSL cert chains (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: add report-sending callback for browser tests Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/url_request/fraudulent_certificate_reporter.h
diff --git a/net/url_request/fraudulent_certificate_reporter.h b/net/url_request/fraudulent_certificate_reporter.h
index 8d5d60a0ef151769355e0995ffc01714b65c8884..eaf1f16546fb6ee29e13004f8ad53fb64d0830f5 100644
--- a/net/url_request/fraudulent_certificate_reporter.h
+++ b/net/url_request/fraudulent_certificate_reporter.h
@@ -16,15 +16,22 @@ class SSLInfo;
// check.
class FraudulentCertificateReporter {
public:
+ // The type of a report: either a pinning violation on a google.com
Ryan Sleevi 2015/03/03 19:16:39 This is a bit of a layering violation (or more apt
+ // site, or a report of an invalid SSL certificate chain (sent as part
+ // of the extended reporting program).
+ enum ReportType { REPORT_TYPE_PIN_VIOLATION, REPORT_TYPE_EXTENDED_REPORTING };
+
virtual ~FraudulentCertificateReporter() {}
- // Sends a report to the report collection server containing the |ssl_info|
- // associated with a connection to |hostname|.
- virtual void SendReport(const std::string& hostname,
+ // Sends a report of the given |type| to the report collection server,
+ // containing the |ssl_info| associated with a connection to
+ // |hostname|. |type| determines the format of the report to be sent
+ // and the endpoint that it gets sent to.
+ virtual void SendReport(ReportType type,
+ const std::string& hostname,
const SSLInfo& ssl_info) = 0;
};
} // namespace net
#endif // NET_URL_REQUEST_FRAUDULENT_CERTIFICATE_REPORTER_H_
-

Powered by Google App Engine
This is Rietveld 408576698